==> nextcloud-10.0.2.tar.bz2: nextcloud/settings/l10n/ar.js <==
OC.L10N.register(
    "settings",
    {
    "Enabled" : "مفعلة",
    "Wrong password" : "كلمة مرور خاطئة",
    "Saved" : "حفظ",
    "No user supplied" : "لم يتم توفير مستخدم ",
    "Unable to change password" : "لا يمكن تغيير كلمة المرور",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "يرجى توفير كلمة مرور المسؤول المستردة, وإلا سيتم فقد جميع بيانات المستخدم ",
    "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
    "test email settings" : "إعدادات البريد التجريبي",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "Invalid request" : "طلب غير مفهوم",
    "Unable to change full name" : "لم يتم التمكن من تغيير اسمك الكامل",
    "Your full name has been changed." : "اسمك الكامل تم تغييره.",
    "Email saved" : "تم حفظ البريد الإلكتروني",
    "Admins can't remove themself from the admin group" : "لا يستطيع المدير إزالة حسابه من مجموعة المديرين",
    "Unable to add user to group %s" : "فشل إضافة المستخدم الى المجموعة %s",
    "Unable to remove user from group %s" : "فشل إزالة المستخدم من المجموعة %s",
    "Couldn't update app." : "تعذر تحديث التطبيق.",
    "Sending..." : "جاري الارسال ...",
    "All" : "الكل",
    "Please wait...." : "الرجاء الانتظار ...",
    "Error while disabling app" : "خطا عند تعطيل البرنامج",
    "Disable" : "إيقاف",
    "Enable" : "تفعيل",
    "Error while enabling app" : "خطا عند تفعيل البرنامج ",
    "Updating...." : "جاري التحديث ...",
    "Error while updating app" : "حصل خطأ أثناء تحديث التطبيق",
    "Updated" : "تم التحديث بنجاح",
    "Uninstalling ...." : "جاري إلغاء التثبيت ...",
    "Uninstall" : "ألغاء التثبيت",
    "Delete" : "إلغاء",
    "Select a profile picture" : "اختر صورة الملف الشخصي ",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Groups" : "مجموعات",
    "undo" : "تراجع",
    "never" : "بتاتا",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
    "__language_name__" : "اللغة العربية",
    "Unlimited" : "غير محدود",
    "None" : "لا شيء",
    "Login" : "تسجيل الدخول",
    "Send mode" : "وضعية الإرسال",
    "Encryption" : "التشفير",
    "Authentication method" : "أسلوب التطابق",
    "Server address" : "عنوان الخادم",
    "Port" : "المنفذ",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "موديل  'fileinfo' الخاص بالـPHP  مفقود . نوصي بتفعيل هذا الموديل للحصول على أفضل النتائج مع خاصية التحقق ",
    "System locale can not be set to a one which supports UTF-8." : "لا يمكن تعيين لغة النظام الى احد اللغات التي تدعم UTF-8.",
    "This means that there might be problems with certain characters in file names." : "هذا يعني انه من الممكن ان يكون هناك مشكلة في بعض الاحرف في اسم الملف.",
    "Cron" : "مجدول",
    "Execute one task with each page loaded" : "قم بتنفيذ مهمة واحدة مع كل صفحة تم تحميلها",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "الملف cron.php تم تسجيله فى خدمه webcron  لاستدعاء الملف cron.php كل  15 دقيقه",
    "Version" : "إصدار",
    "Sharing" : "مشاركة",
    "Allow apps to use the Share API" : "السماح للتطبيقات بالمشاركة عن طريق الAPI",
    "Allow users to share via link" : "السماح للمستخدم بمشاركة الملف عن طريق رابط",
    "Allow public uploads" : "السماح بالرفع للعامة ",
    "Expire after " : "ينتهي بعد",
    "days" : "أيام",
    "Allow resharing" : "السماح بإعادة المشاركة ",
    "Documentation:" : "التوثيق",
    "Uninstall App" : "أزالة تطبيق",
    "Valid until" : "صالح حتى",
    "Forum" : "منتدى",
    "Profile picture" : "صورة الملف الشخصي",
    "Upload new" : "رفع الان",
    "Remove image" : "إزالة الصورة",
    "Cancel" : "الغاء",
    "Email" : "البريد الإلكترونى",
    "Your email address" : "عنوانك البريدي",
    "Password" : "كلمة المرور",
    "Current password" : "كلمات السر الحالية",
    "New password" : "كلمات سر جديدة",
    "Change password" : "عدل كلمة السر",
    "Language" : "اللغة",
    "Help translate" : "ساعد في الترجمه",
    "Get the apps to sync your files" : "احصل على التطبيقات لمزامنة ملفاتك",
    "Show First Run Wizard again" : "ابدأ خطوات بداية التشغيل من جديد",
    "Name" : "الاسم",
    "Username" : "إسم المستخدم",
    "E-Mail" : "بريد إلكتروني",
    "Create" : "انشئ",
    "Admin Recovery Password" : "استعادة كلمة المرور للمسؤول",
    "Enter the recovery password in order to recover the users files during password change" : "ادخل كلمة المرور المستعادة من اجل استرداد ملفات المستخدمين اثناء تغيير كلمة المرور",
    "Everyone" : "الجميع",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "يرجى ادخال تخزين quota (مثل:\"512 MB\" او  \"12 GB\")",
    "Other" : "شيء آخر",
    "Quota" : "حصه",
    "change full name" : "تغيير اسمك الكامل",
    "set new password" : "اعداد كلمة مرور جديدة",
    "Default" : "افتراضي",
    "Language changed" : "تم تغيير اللغة",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "هل أنت متأكد انك تريد إضافة \"{domain}\" كنطاق موثوق فيه.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "كل شيء (مشاكل فادحة, اخطاء , تحذيرات , معلومات , تصحيح الاخطاء)",
    "Info, warnings, errors and fatal issues" : "معلومات , تحذيرات , اخطاء , مشاكل فادحة ",
    "Warnings, errors and fatal issues" : "تحذيرات , اخطاء , مشاكل فادحة ",
    "Errors and fatal issues" : "اخطاء ومشاكل فادحة ",
    "Fatal issues only" : "مشاكل فادحة فقط ",
    "Log" : "سجل",
    "Download logfile" : "تنزيل ملف السجل",
    "More" : "المزيد",
    "Less" : "أقل",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "قاعدة البيانات المستخدمة هي SQLite. ننصح باستخدام قاعدة بيانات أخرى للحصول على أداء افضل.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "استخدام SQLite غير مناسب خاصتا اذا تم استخدام برنامج المزامنة على الجهاز الشخصي.",
    "Group" : "مجموعة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-12.0.5.tar.bz2: nextcloud/settings/l10n/ar.js <==
OC.L10N.register(
    "settings",
    {
    "Your apps" : "تطبيقاتك",
    "Updates" : "التحديثات",
    "Wrong password" : "كلمة مرور خاطئة",
    "Saved" : "حفظ",
    "No user supplied" : "لم يتم توفير مستخدم ",
    "Unable to change password" : "لا يمكن تغيير كلمة المرور",
    "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
    "Wrong admin recovery password. Please check the password and try again." : "خطا في كلمة مرور المسؤول المستردة, يرجى التاكد من كلمة المرور والمحاولة مرة اخرى.",
    "Unable to change full name" : "لم يتم التمكن من تغيير اسمك الكامل",
    "Your full name has been changed." : "اسمك الكامل تم تغييره.",
    "Email saved" : "تم حفظ البريد الإلكتروني",
    "Couldn't update app." : "تعذر تحديث التطبيق.",
    "Add trusted domain" : "أضافة نطاق موثوق فيه",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "All" : "الكل",
    "Error while disabling app" : "خطا عند تعطيل البرنامج",
    "Disable" : "إيقاف",
    "Enable" : "تفعيل",
    "Error while enabling app" : "خطا عند تفعيل البرنامج ",
    "Updated" : "تم التحديث بنجاح",
    "Copy" : "نسخ",
    "Delete" : "إلغاء",
    "Select a profile picture" : "اختر صورة الملف الشخصي ",
    "Very weak password" : "كلمة السر ضعيفة جدا",
    "Weak password" : "كلمة السر ضعيفة",
    "Good password" : "كلمة السر جيدة",
    "Strong password" : "كلمة السر قوية",
    "Groups" : "مجموعات",
    "undo" : "تراجع",
    "never" : "بتاتا",
    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
    "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
    "Documentation:" : "التوثيق",
    "Valid until" : "صالح حتى",
    "Forum" : "منتدى",
    "None" : "لا شيء",
    "Login" : "تسجيل الدخول",
    "Send mode" : "وضعية الإرسال",
    "Encryption" : "التشفير",
    "Authentication method" : "أسلوب التطابق",
    "Server address" : "عنوان الخادم",
    "Port" : "المنفذ",
    "Test email settings" : "فحص إعدادات البريد الإلكتروني",
    "System locale can not be set to a one which supports UTF-8." : "لا يمكن تعيين لغة النظام الى احد اللغات التي تدعم UTF-8.",
    "Execute one task with each page loaded" : "قم بتنفيذ مهمة واحدة مع كل صفحة تم تحميلها",
    "Version" : "إصدار",
    "Sharing" : "مشاركة",
    "Allow apps to use the Share API" : "السماح للتطبيقات بالمشاركة عن طريق الAPI",
    "Allow users to share via link" : "السماح للمستخدم بمشاركة الملف عن طريق رابط",
    "Allow public uploads" : "السماح بالرفع للعامة ",
    "Expire after " : "ينتهي بعد",
    "days" : "أيام",
    "Allow resharing" : "السماح بإعادة المشاركة ",
    "Profile picture" : "صورة الملف الشخصي",
    "Upload new" : "رفع الان",
    "Remove image" : "إزالة الصورة",
    "Cancel" : "الغاء",
    "Email" : "البريد الإلكترونى",
    "Your email address" : "عنوانك البريدي",
    "Language" : "اللغة",
    "Help translate" : "ساعد في الترجمه",
    "Password" : "كلمة المرور",
    "Current password" : "كلمات السر الحالية",
    "New password" : "كلمات سر جديدة",
    "Change password" : "عدل كلمة السر",
    "Username" : "إسم المستخدم",
    "Settings" : "الإعدادات",
    "E-Mail" : "بريد إلكتروني",
    "Create" : "انشئ",
    "Admin Recovery Password" : "استعادة كلمة المرور للمسؤول",
    "Enter the recovery password in order to recover the users files during password change" : "ادخل كلمة المرور المستعادة من اجل استرداد ملفات المستخدمين اثناء تغيير كلمة المرور",
    "Everyone" : "الجميع",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "يرجى ادخال تخزين quota (مثل:\"512 MB\" او  \"12 GB\")",
    "Unlimited" : "غير محدود",
    "Other" : "شيء آخر",
    "Quota" : "حصه",
    "change full name" : "تغيير اسمك الكامل",
    "set new password" : "اعداد كلمة مرور جديدة",
    "Default" : "افتراضي",
    "Enabled" : "مفعلة",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "يرجى توفير كلمة مرور المسؤول المستردة, وإلا سيتم فقد جميع بيانات المستخدم ",
    "test email settings" : "فحص إعدادات البريد الإلكتروني",
    "Invalid request" : "طلب غير مفهوم",
    "Admins can't remove themself from the admin group" : "لا يستطيع المدير إزالة حسابه من مجموعة المديرين",
    "Unable to add user to group %s" : "فشل إضافة المستخدم الى المجموعة %s",
    "Unable to remove user from group %s" : "فشل إزالة المستخدم من المجموعة %s",
    "Sending..." : "جاري الارسال ...",
    "Updating...." : "جاري التحديث ...",
    "Error while updating app" : "حصل خطأ أثناء تحديث التطبيق",
    "Uninstalling ...." : "جاري إلغاء التثبيت ...",
    "Uninstall" : "ألغاء التثبيت",
    "__language_name__" : "اللغة العربية",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "موديل  'fileinfo' الخاص بالـPHP  مفقود . نوصي بتفعيل هذا الموديل للحصول على أفضل النتائج مع خاصية التحقق ",
    "This means that there might be problems with certain characters in file names." : "هذا يعني انه من الممكن ان يكون هناك مشكلة في بعض الاحرف في اسم الملف.",
    "Cron" : "مجدول",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "الملف cron.php تم تسجيله فى خدمه webcron  لاستدعاء الملف cron.php كل  15 دقيقه",
    "Get the apps to sync your files" : "احصل على التطبيقات لمزامنة ملفاتك",
    "Show First Run Wizard again" : "ابدأ خطوات بداية التشغيل من جديد",
    "Name" : "الاسم"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
